You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by da...@apache.org on 2019/10/10 07:07:47 UTC

[camel-quarkus] branch fix245 created (now 4da69a9)

This is an automated email from the ASF dual-hosted git repository.

davsclaus pushed a change to branch fix245
in repository https://gitbox.apache.org/repos/asf/camel-quarkus.git.


      at 4da69a9  Remove build scripts no longer needed as we generate this via Camel Maven tooling like we do at Apache Camel

This branch includes the following new commits:

     new aef16d1  Fixes #45 to update the extensions list in the website docs also.
     new b264232  Reorder
     new 3345f84  Polished
     new d9e10eb  Add todo
     new 1552f1f  Fixes #45 to update the extensions list in the website docs also.
     new 4da69a9  Remove build scripts no longer needed as we generate this via Camel Maven tooling like we do at Apache Camel

The 6 revisions listed above as "new" are entirely new to this
repository and will be described in separate emails.  The revisions
listed as "add" were already present in the repository and have only
been added to this reference.



[camel-quarkus] 01/06: Fixes #45 to update the extensions list in the website docs also.

Posted by da...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

davsclaus pushed a commit to branch fix245
in repository https://gitbox.apache.org/repos/asf/camel-quarkus.git

commit aef16d1e8c74abdfc434c11e9c2de92a0cdb1367
Author: Claus Ibsen <cl...@gmail.com>
AuthorDate: Wed Oct 9 12:20:43 2019 +0200

    Fixes #45 to update the extensions list in the website docs also.
---
 catalog/camel-quarkus-catalog/pom.xml                 |  4 ++--
 extensions/readme.adoc                                |  6 +++---
 ...admeMojo.java => UpdateDocExtensionsListMojo.java} | 19 ++++++++++++-------
 3 files changed, 17 insertions(+), 12 deletions(-)

diff --git a/catalog/camel-quarkus-catalog/pom.xml b/catalog/camel-quarkus-catalog/pom.xml
index 7ce0e6e..d497e6d 100644
--- a/catalog/camel-quarkus-catalog/pom.xml
+++ b/catalog/camel-quarkus-catalog/pom.xml
@@ -86,10 +86,10 @@
                 </dependencies>
                 <executions>
                     <execution>
-                        <!-- prepare the catalog, readme files, etc. -->
+                        <!-- prepare the catalog and update doc files, etc. -->
                         <goals>
                             <goal>prepare-catalog-quarkus</goal>
-                            <goal>prepare-extensions-readme</goal>
+                            <goal>update-doc-extensions-list</goal>
                         </goals>
                         <phase>process-resources</phase>
                     </execution>
diff --git a/extensions/readme.adoc b/extensions/readme.adoc
index c73ff15..8fee6ec 100644
--- a/extensions/readme.adoc
+++ b/extensions/readme.adoc
@@ -92,7 +92,7 @@ Number of Camel data formats: 3 in 3 JAR artifacts (0 deprecated)
 
 | link:https://camel.apache.org/components/latest/csv-dataformat.html[CSV] (camel-quarkus-csv) | 0.2 | The CSV data format is used for handling CSV payloads.
 
-| link:https://camel.apache.org/components/latest/mime-multipart-dataformat.html[MIME Multipart] (camel-quarkus-mail) | 0.2 | The MIME Multipart data format can marshal a Camel message with attachments into a Camel message having a MIME-Multipart message as message body (and no attachments), and vise-versa when unmarshalling.
+| link:https://camel.apache.org/components/latest/mime-multipart-dataformat.html[MIME Multipart] (camel-quarkus-mail) | 0.2 | The MIME Multipart data format is used for marshalling Camel messages with attachments into MIME-Multipart message, and vise-versa.
 
 | link:https://camel.apache.org/components/latest/zipfile-dataformat.html[Zip File] (camel-quarkus-zipfile) | 0.2 | The Zip File data format is a message compression and de-compression format of zip files.
 |===
@@ -110,11 +110,11 @@ Number of Camel languages: 8 in 2 JAR artifacts (0 deprecated)
 
 | link:https://camel.apache.org/components/latest/bean-language.html[Bean method] (camel-quarkus-bean) | 0.2 | To use a Java bean (aka method call) in Camel expressions or predicates.
 
-| link:https://camel.apache.org/components/latest/constant-language.html[Constant] (camel-quarkus-core) | 0.2 | To use a constant value in Camel expressions or predicates. Important: this is a fixed constant value that is only set once during starting up the route, do not use this if you want dynamic values during routing.
+| link:https://camel.apache.org/components/latest/constant-language.html[Constant] (camel-quarkus-core) | 0.2 | To use a constant value in Camel expressions or predicates.
 
 | link:https://camel.apache.org/components/latest/exchangeProperty-language.html[ExchangeProperty] (camel-quarkus-core) | 0.2 | To use a Camel Exchange property in expressions or predicates.
 
-| link:https://camel.apache.org/components/latest/file-language.html[File] (camel-quarkus-core) | 0.2 | For expressions and predicates using the file/simple language
+| link:https://camel.apache.org/components/latest/file-language.html[File] (camel-quarkus-core) | 0.2 | For expressions and predicates using the file/simple language.
 
 | link:https://camel.apache.org/components/latest/header-language.html[Header] (camel-quarkus-core) | 0.2 | To use a Camel Message header in expressions or predicates.
 
diff --git a/build/scripts/list-camel-quarkus-extensions.groovy b/build/scripts/list-camel-quarkus-extensions.groovy
deleted file mode 100644
index a2d0caa..0000000
--- a/build/scripts/list-camel-quarkus-extensions.groovy
+++ /dev/null
@@ -1,43 +0,0 @@
-/*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
- *
- *      http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-import java.util.stream.Collectors
-
-/* Keep in sync with the current file name */
-@groovy.transform.Field static final String currentScript = "list-camel-quarkus-extensions.groovy";
-final File extensionsPomPath = new File("${project.basedir}/pom.xml")
-final File componentExtensionsAdocPath = new File("${project.basedir}/../docs/modules/ROOT/pages/_partials/component-extensions.adoc")
-final File commonExtensionsAdocPath = new File("${project.basedir}/../docs/modules/ROOT/pages/_partials/common-extensions.adoc")
-
-def parser = new XmlParser()
-def pom = parser.parseText(extensionsPomPath.getText('UTF-8'))
-final Set componentExtensions = new TreeSet()
-final Set commonExtensions = new TreeSet()
-pom.modules.module.each { node ->
-    final String key = node.text().trim()
-    if (key.startsWith("core") || key.endsWith("-common")) {
-        commonExtensions.add(key)
-    } else {
-        componentExtensions.add(key)
-    }
-}
-
-void writeFile(File f, Set<String> keys) {
-    f.setText('// Generated by ' + currentScript +'\n' + keys.stream().map { k -> '* `camel-quarkus-' + k +'`\n' }.collect(Collectors.joining()), 'UTF-8')
-}
-
-writeFile(componentExtensionsAdocPath, componentExtensions)
-writeFile(commonExtensionsAdocPath, commonExtensions)
diff --git a/docs/modules/ROOT/pages/_partials/common-extensions.adoc b/docs/modules/ROOT/pages/_partials/common-extensions.adoc
deleted file mode 100644
index 5c4952e..0000000
--- a/docs/modules/ROOT/pages/_partials/common-extensions.adoc
+++ /dev/null
@@ -1,5 +0,0 @@
-// Generated by list-camel-quarkus-extensions.groovy
-* `camel-quarkus-core`
-* `camel-quarkus-core-cloud`
-* `camel-quarkus-http-common`
-* `camel-quarkus-xml-common`
diff --git a/docs/modules/ROOT/pages/_partials/component-extensions.adoc b/docs/modules/ROOT/pages/_partials/component-extensions.adoc
deleted file mode 100644
index f8a301c..0000000
--- a/docs/modules/ROOT/pages/_partials/component-extensions.adoc
+++ /dev/null
@@ -1,24 +0,0 @@
-// Generated by list-camel-quarkus-extensions.groovy
-* `camel-quarkus-aws-eks`
-* `camel-quarkus-aws-s3`
-* `camel-quarkus-aws-sns`
-* `camel-quarkus-aws-sqs`
-* `camel-quarkus-bean`
-* `camel-quarkus-csv`
-* `camel-quarkus-direct`
-* `camel-quarkus-infinispan`
-* `camel-quarkus-jdbc`
-* `camel-quarkus-log`
-* `camel-quarkus-mail`
-* `camel-quarkus-microprofile-metrics`
-* `camel-quarkus-netty-http`
-* `camel-quarkus-paho`
-* `camel-quarkus-platform-http`
-* `camel-quarkus-reactive-executor`
-* `camel-quarkus-rest`
-* `camel-quarkus-salesforce`
-* `camel-quarkus-servlet`
-* `camel-quarkus-support`
-* `camel-quarkus-timer`
-* `camel-quarkus-twitter`
-* `camel-quarkus-zipfile`
diff --git a/extensions/pom.xml b/extensions/pom.xml
index a3c920d..3ba3193 100644
--- a/extensions/pom.xml
+++ b/extensions/pom.xml
@@ -86,32 +86,6 @@
                     <itestParentPath>../integration-tests/pom.xml</itestParentPath>
                 </configuration>
             </plugin>
-            <plugin>
-                <groupId>org.codehaus.gmaven</groupId>
-                <artifactId>groovy-maven-plugin</artifactId>
-                <version>${groovy-maven-plugin.version}</version>
-                <inherited>false</inherited>
-                <executions>
-                    <execution>
-                        <id>list-camel-quarkus-extensions</id>
-                        <goals>
-                            <goal>execute</goal>
-                        </goals>
-                        <phase>validate</phase>
-                        <configuration>
-                            <source>file:///${project.basedir}/../build/scripts/list-camel-quarkus-extensions.groovy</source>
-                        </configuration>
-                    </execution>
-                </executions>
-                <dependencies>
-                    <dependency>
-                        <groupId>org.codehaus.groovy</groupId>
-                        <artifactId>groovy-all</artifactId>
-                        <version>${groovy.version}</version>
-                        <type>pom</type>
-                    </dependency>
-                </dependencies>
-            </plugin>
         </plugins>
     </build>
 </project>


[camel-quarkus] 05/06: Fixes #45 to update the extensions list in the website docs also.

Posted by da...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

davsclaus pushed a commit to branch fix245
in repository https://gitbox.apache.org/repos/asf/camel-quarkus.git

commit 1552f1fdb90e0d651ee8ddbf0c9b81ebbb6d7d79
Author: Claus Ibsen <cl...@gmail.com>
AuthorDate: Thu Oct 10 09:00:51 2019 +0200

    Fixes #45 to update the extensions list in the website docs also.
---
 .../pages/list-of-camel-quarkus-extensions.adoc    | 141 ++++++++++++++++++++-
 .../quarkus/maven/UpdateDocExtensionsListMojo.java |  52 +++++++-
 2 files changed, 185 insertions(+), 8 deletions(-)

diff --git a/docs/modules/ROOT/pages/list-of-camel-quarkus-extensions.adoc b/docs/modules/ROOT/pages/list-of-camel-quarkus-extensions.adoc
index 32876b6..b398c5d 100644
--- a/docs/modules/ROOT/pages/list-of-camel-quarkus-extensions.adoc
+++ b/docs/modules/ROOT/pages/list-of-camel-quarkus-extensions.adoc
@@ -1,10 +1,143 @@
 [list-of-camel-quarkus-extensions]
 = List of Apache Camel extensions for Quarkus
 
-As of Camel Quarkus {camel-quarkus-last-release} the following Camel components are supported on Quarkus:
+As of Camel Quarkus {camel-quarkus-last-release} the following Camel artifacts are supported on Quarkus:
 
-include::{partialsdir}/component-extensions.adoc[]
+== Camel Components
 
-In addition to the above extensions there are the following ancillary extensions:
+// components: START
+Number of Camel components: 22 in 18 JAR artifacts (0 deprecated)
 
-include::{partialsdir}/common-extensions.adoc[]
+[width="100%",cols="4,1,5",options="header"]
+|===
+| Component | Available From | Description
+
+| link:https://camel.apache.org/components/latest/aws-eks-component.html[AWS EKS] (camel-quarkus-aws-eks) +
+`aws-eks:label` | 0.2 | The aws-kms is used for managing Amazon EKS
+
+| link:https://camel.apache.org/components/latest/aws-s3-component.html[AWS S3 Storage Service] (camel-quarkus-aws-s3) +
+`aws-s3://bucketNameOrArn` | 0.2 | The aws-s3 component is used for storing and retrieving object from Amazon S3 Storage Service.
+
+| link:https://camel.apache.org/components/latest/aws-sns-component.html[AWS Simple Notification System] (camel-quarkus-aws-sns) +
+`aws-sns:topicNameOrArn` | 0.2 | The aws-sns component is used for sending messages to an Amazon Simple Notification Topic.
+
+| link:https://camel.apache.org/components/latest/aws-sqs-component.html[AWS Simple Queue Service] (camel-quarkus-aws-sqs) +
+`aws-sqs:queueNameOrArn` | 0.2 | The aws-sqs component is used for sending and receiving messages to Amazon's SQS service.
+
+| link:https://camel.apache.org/components/latest/bean-component.html[Bean] (camel-quarkus-bean) +
+`bean:beanName` | 0.2 | The bean component is for invoking Java beans from Camel.
+
+| link:https://camel.apache.org/components/latest/class-component.html[Class] (camel-quarkus-bean) +
+`class:beanName` | 0.2 | The class component is for invoking Java classes (Java beans) from Camel.
+
+| link:https://camel.apache.org/components/latest/direct-component.html[Direct] (camel-quarkus-direct) +
+`direct:name` | 0.2 | The direct component provides direct, synchronous call to another endpoint from the same CamelContext.
+
+| link:https://camel.apache.org/components/latest/infinispan-component.html[Infinispan] (camel-quarkus-infinispan) +
+`infinispan:cacheName` | 0.2 | For reading/writing from/to Infinispan distributed key/value store and data grid.
+
+| link:https://camel.apache.org/components/latest/jdbc-component.html[JDBC] (camel-quarkus-jdbc) +
+`jdbc:dataSourceName` | 0.2 | The jdbc component enables you to access databases through JDBC, where SQL queries are sent in the message body.
+
+| link:https://camel.apache.org/components/latest/log-component.html[Log] (camel-quarkus-log) +
+`log:loggerName` | 0.2 | The log component logs message exchanges to the underlying logging mechanism.
+
+| link:https://camel.apache.org/components/latest/mail-component.html[Mail] (camel-quarkus-mail) +
+`imap:host:port` | 0.2 | To send or receive emails using imap/pop3 or smtp protocols.
+
+| link:https://camel.apache.org/components/latest/microprofile-metrics-component.html[MicroProfile Metrics] (camel-quarkus-microprofile-metrics) +
+`microprofile-metrics:metricType:metricName` | 0.2 | Camel metrics exposed with Eclipse MicroProfile Metrics
+
+| link:https://camel.apache.org/components/latest/netty-http-component.html[Netty HTTP] (camel-quarkus-netty-http) +
+`netty-http:protocol:host:port/path` | 0.2 | Netty HTTP server and client using the Netty 4.x library.
+
+| link:https://camel.apache.org/components/latest/paho-component.html[Paho] (camel-quarkus-paho) +
+`paho:topic` | 0.2 | Component for communicating with MQTT M2M message brokers using Eclipse Paho MQTT Client.
+
+| link:https://camel.apache.org/components/latest/rest-component.html[REST] (camel-quarkus-rest) +
+`rest:method:path:uriTemplate` | 0.2 | The rest component is used for either hosting REST services (consumer) or calling external REST services (producer).
+
+| link:https://camel.apache.org/components/latest/rest-api-component.html[REST API] (camel-quarkus-rest) +
+`rest-api:path/contextIdPattern` | 0.2 | The rest-api component is used for providing Swagger API of the REST services which has been defined using the rest-dsl in Camel.
+
+| link:https://camel.apache.org/components/latest/salesforce-component.html[Salesforce] (camel-quarkus-salesforce) +
+`salesforce:operationName:topicName` | 0.2 | The salesforce component is used for integrating Camel with the massive Salesforce API.
+
+| link:https://camel.apache.org/components/latest/servlet-component.html[Servlet] (camel-quarkus-servlet) +
+`servlet:contextPath` | 0.2 | To use a HTTP Servlet as entry for Camel routes when running in a servlet container.
+
+| link:https://camel.apache.org/components/latest/timer-component.html[Timer] (camel-quarkus-timer) +
+`timer:timerName` | 0.2 | The timer component is used for generating message exchanges when a timer fires.
+
+| link:https://camel.apache.org/components/latest/twitter-directmessage-component.html[Twitter Direct Message] (camel-quarkus-twitter) +
+`twitter-directmessage:user` | 0.2 | The Twitter Direct Message Component consumes/produces user's direct messages.
+
+| link:https://camel.apache.org/components/latest/twitter-search-component.html[Twitter Search] (camel-quarkus-twitter) +
+`twitter-search:keywords` | 0.2 | The Twitter Search component consumes search results.
+
+| link:https://camel.apache.org/components/latest/twitter-timeline-component.html[Twitter Timeline] (camel-quarkus-twitter) +
+`twitter-timeline:timelineType` | 0.2 | The Twitter Timeline component consumes twitter timeline or update the status of specific user.
+
+|===
+// components: END
+
+== Camel Data Formats
+
+// dataformats: START
+Number of Camel data formats: 3 in 3 JAR artifacts (0 deprecated)
+
+[width="100%",cols="4,1,5",options="header"]
+|===
+| Data Format | Available From | Description
+
+| link:https://camel.apache.org/components/latest/csv-dataformat.html[CSV] (camel-quarkus-csv) | 0.2 | The CSV data format is used for handling CSV payloads.
+
+| link:https://camel.apache.org/components/latest/mime-multipart-dataformat.html[MIME Multipart] (camel-quarkus-mail) | 0.2 | The MIME Multipart data format is used for marshalling Camel messages with attachments into MIME-Multipart message, and vise-versa.
+
+| link:https://camel.apache.org/components/latest/zipfile-dataformat.html[Zip File] (camel-quarkus-zipfile) | 0.2 | The Zip File data format is a message compression and de-compression format of zip files.
+|===
+// dataformats: END
+
+== Camel Languages
+
+// languages: START
+Number of Camel languages: 8 in 2 JAR artifacts (0 deprecated)
+
+[width="100%",cols="4,1,5",options="header"]
+|===
+| Language | Available From | Description
+
+| link:https://camel.apache.org/components/latest/bean-language.html[Bean method] (camel-quarkus-bean) | 0.2 | To use a Java bean (aka method call) in Camel expressions or predicates.
+
+| link:https://camel.apache.org/components/latest/constant-language.html[Constant] (camel-quarkus-core) | 0.2 | To use a constant value in Camel expressions or predicates.
+
+| link:https://camel.apache.org/components/latest/exchangeProperty-language.html[ExchangeProperty] (camel-quarkus-core) | 0.2 | To use a Camel Exchange property in expressions or predicates.
+
+| link:https://camel.apache.org/components/latest/file-language.html[File] (camel-quarkus-core) | 0.2 | For expressions and predicates using the file/simple language.
+
+| link:https://camel.apache.org/components/latest/header-language.html[Header] (camel-quarkus-core) | 0.2 | To use a Camel Message header in expressions or predicates.
+
+| link:https://camel.apache.org/components/latest/ref-language.html[Ref] (camel-quarkus-core) | 0.2 | Reference to an existing Camel expression or predicate, which is looked up from the Camel registry.
+
+| link:https://camel.apache.org/components/latest/simple-language.html[Simple] (camel-quarkus-core) | 0.2 | To use Camels built-in Simple language in Camel expressions or predicates.
+
+| link:https://camel.apache.org/components/latest/tokenize-language.html[Tokenize] (camel-quarkus-core) | 0.2 | To use Camel message body or header with a tokenizer in Camel expressions or predicates.
+|===
+// languages: END
+
+== Miscellaneous Extensions
+
+// others: START
+Number of miscellaneous extensions: 3 in 3 JAR artifacts (0 deprecated)
+
+[width="100%",cols="4,1,5",options="header"]
+|===
+| Extension | Available From | Description
+
+| (camel-quarkus-core-cloud) | 0.2 | The Camel Quarkus core cloud module
+
+| (camel-quarkus-platform-http) | 0.2.1 | HTTP platform component is used for integrating Camel HTTP with Quarkus HTTP layer
+
+| (camel-quarkus-reactive-executor) | 0.2.1 | To use Quarkus reactive executor with Camel
+|===
+// others: END
diff --git a/tooling/maven/package-maven-plugin/src/main/java/org/apache/camel/quarkus/maven/UpdateDocExtensionsListMojo.java b/tooling/maven/package-maven-plugin/src/main/java/org/apache/camel/quarkus/maven/UpdateDocExtensionsListMojo.java
index b5e7697..705b8af 100644
--- a/tooling/maven/package-maven-plugin/src/main/java/org/apache/camel/quarkus/maven/UpdateDocExtensionsListMojo.java
+++ b/tooling/maven/package-maven-plugin/src/main/java/org/apache/camel/quarkus/maven/UpdateDocExtensionsListMojo.java
@@ -188,7 +188,18 @@ public class UpdateDocExtensionsListMojo extends AbstractMojo {
                 getLog().warn("No readme.adoc file: " + file);
             }
 
-            // TODO: update websiteDocFile
+            // update doc in the website dir
+            file = websiteDocFile;
+            exists = file.exists();
+            changed = templateComponents(components, count, deprecated);
+            updated = updateComponents(file, changed);
+            if (updated) {
+                getLog().info("Updated website doc file: " + file);
+            } else if (exists) {
+                getLog().debug("No changes to website doc file: " + file);
+            } else {
+                getLog().warn("No website doc file: " + file);
+            }
 
         } catch (IOException e) {
             throw new MojoFailureException("Error due " + e.getMessage(), e);
@@ -251,7 +262,18 @@ public class UpdateDocExtensionsListMojo extends AbstractMojo {
                 getLog().warn("No readme.adoc file: " + file);
             }
 
-            // TODO: update websiteDocFile
+            // update doc in the website dir
+            file = websiteDocFile;
+            exists = file.exists();
+            changed = templateDataFormats(dataFormats, count, deprecated);
+            updated = updateDataFormats(file, changed);
+            if (updated) {
+                getLog().info("Updated website doc file: " + file);
+            } else if (exists) {
+                getLog().debug("No changes to website doc file: " + file);
+            } else {
+                getLog().warn("No website doc file: " + file);
+            }
 
         } catch (IOException e) {
             throw new MojoFailureException("Error due " + e.getMessage(), e);
@@ -308,7 +330,18 @@ public class UpdateDocExtensionsListMojo extends AbstractMojo {
                 getLog().warn("No readme.adoc file: " + file);
             }
 
-            // TODO: update websiteDocFile
+            // update doc in the website dir
+            file = websiteDocFile;
+            exists = file.exists();
+            changed = templateLanguages(languages, count, deprecated);
+            updated = updateLanguages(file, changed);
+            if (updated) {
+                getLog().info("Updated website doc file: " + file);
+            } else if (exists) {
+                getLog().debug("No changes to website doc file: " + file);
+            } else {
+                getLog().warn("No website doc file: " + file);
+            }
 
         } catch (IOException e) {
             throw new MojoFailureException("Error due " + e.getMessage(), e);
@@ -359,7 +392,18 @@ public class UpdateDocExtensionsListMojo extends AbstractMojo {
                 getLog().warn("No readme.adoc file: " + file);
             }
 
-            // TODO: update websiteDocFile
+            // update doc in the website dir
+            file = websiteDocFile;
+            exists = file.exists();
+            changed = templateOthers(others, count, deprecated);
+            updated = updateOthers(file, changed);
+            if (updated) {
+                getLog().info("Updated website doc file: " + file);
+            } else if (exists) {
+                getLog().debug("No changes to website doc file: " + file);
+            } else {
+                getLog().warn("No website doc file: " + file);
+            }
 
         } catch (IOException e) {
             throw new MojoFailureException("Error due " + e.getMessage(), e);


[camel-quarkus] 02/06: Reorder

Posted by da...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

davsclaus pushed a commit to branch fix245
in repository https://gitbox.apache.org/repos/asf/camel-quarkus.git

commit b264232bd83693ddf9171d86bc6468ea68fc95d5
Author: Claus Ibsen <cl...@gmail.com>
AuthorDate: Wed Oct 9 12:24:12 2019 +0200

    Reorder
---
 .../quarkus/maven/UpdateDocExtensionsListMojo.java | 237 +++++++++++----------
 1 file changed, 122 insertions(+), 115 deletions(-)

diff --git a/tooling/maven/package-maven-plugin/src/main/java/org/apache/camel/quarkus/maven/UpdateDocExtensionsListMojo.java b/tooling/maven/package-maven-plugin/src/main/java/org/apache/camel/quarkus/maven/UpdateDocExtensionsListMojo.java
index 0cf24b4..b9d1148 100644
--- a/tooling/maven/package-maven-plugin/src/main/java/org/apache/camel/quarkus/maven/UpdateDocExtensionsListMojo.java
+++ b/tooling/maven/package-maven-plugin/src/main/java/org/apache/camel/quarkus/maven/UpdateDocExtensionsListMojo.java
@@ -89,10 +89,16 @@ public class UpdateDocExtensionsListMojo extends AbstractMojo {
     protected File othersDir;
 
     /**
-     * The directory for components
+     * The directory for extensions
      */
     @Parameter(defaultValue = "${project.directory}/../../../extensions")
-    protected File readmeComponentsDir;
+    protected File readmeExtensionsDir;
+
+    /**
+     * The website doc for extensions
+     */
+    @Parameter(defaultValue = "${project.directory}/../../../docs/modules/ROOT/pages/list-of-camel-quarkus-extensions.adoc")
+    protected File websiteDocFile;
 
     /**
      * Maven ProjectHelper.
@@ -109,65 +115,12 @@ public class UpdateDocExtensionsListMojo extends AbstractMojo {
      */
     @Override
     public void execute() throws MojoExecutionException, MojoFailureException {
-        // update readme file in extensions
         executeComponentsReadme();
-        executeLanguagesReadme();
         executeDataFormatsReadme();
+        executeLanguagesReadme();
         executeOthersReadme();
     }
 
-    protected void executeOthersReadme() throws MojoExecutionException, MojoFailureException {
-        Set<File> otherFiles = new TreeSet<>();
-
-        if (othersDir != null && othersDir.isDirectory()) {
-            File[] files = othersDir.listFiles();
-            if (files != null) {
-                otherFiles.addAll(Arrays.asList(files));
-            }
-        }
-
-        try {
-            List<OtherModel> others = new ArrayList<>();
-            for (File file : otherFiles) {
-                String json = loadText(new FileInputStream(file));
-                OtherModel model = generateOtherModel(json);
-                others.add(model);
-            }
-
-            // sort the models
-            Collections.sort(others, new OtherComparator());
-
-            // how many different artifacts
-            int count = others.stream()
-                    .map(OtherModel::getArtifactId)
-                    .collect(toSet()).size();
-
-            // how many deprecated
-            long deprecated = others.stream()
-                    .filter(o -> "true".equals(o.getDeprecated()))
-                    .count();
-
-            // update the big readme file in the components dir
-            File file = new File(readmeComponentsDir, "readme.adoc");
-
-            // update regular components
-            boolean exists = file.exists();
-            String changed = templateOthers(others, count, deprecated);
-            boolean updated = updateOthers(file, changed);
-
-            if (updated) {
-                getLog().info("Updated readme.adoc file: " + file);
-            } else if (exists) {
-                getLog().debug("No changes to readme.adoc file: " + file);
-            } else {
-                getLog().warn("No readme.adoc file: " + file);
-            }
-
-        } catch (IOException e) {
-            throw new MojoFailureException("Error due " + e.getMessage(), e);
-        }
-    }
-
     protected void executeComponentsReadme() throws MojoExecutionException, MojoFailureException {
         Set<File> componentFiles = new TreeSet<>();
 
@@ -224,7 +177,7 @@ public class UpdateDocExtensionsListMojo extends AbstractMojo {
 
             // update the big readme file in the core/components dir
             File file;
-            file = new File(readmeComponentsDir, "readme.adoc");
+            file = new File(readmeExtensionsDir, "readme.adoc");
 
             // update regular components
             boolean exists = file.exists();
@@ -273,8 +226,8 @@ public class UpdateDocExtensionsListMojo extends AbstractMojo {
 
             // how many different artifacts
             int count = models.stream()
-                        .map(DataFormatModel::getArtifactId)
-                        .collect(toSet()).size();
+                    .map(DataFormatModel::getArtifactId)
+                    .collect(toSet()).size();
 
             // how many deprecated
             long deprecated = models.stream()
@@ -289,7 +242,7 @@ public class UpdateDocExtensionsListMojo extends AbstractMojo {
 
             // update the big readme file in the core/components dir
             File file;
-            file = new File(readmeComponentsDir, "readme.adoc");
+            file = new File(readmeExtensionsDir, "readme.adoc");
 
             // update regular data formats
             boolean exists = file.exists();
@@ -348,7 +301,7 @@ public class UpdateDocExtensionsListMojo extends AbstractMojo {
 
             // update the big readme file in the core/components dir
             File file;
-            file = new File(readmeComponentsDir, "readme.adoc");
+            file = new File(readmeExtensionsDir, "readme.adoc");
 
             // update regular data formats
             boolean exists = file.exists();
@@ -368,6 +321,58 @@ public class UpdateDocExtensionsListMojo extends AbstractMojo {
         }
     }
 
+    protected void executeOthersReadme() throws MojoExecutionException, MojoFailureException {
+        Set<File> otherFiles = new TreeSet<>();
+
+        if (othersDir != null && othersDir.isDirectory()) {
+            File[] files = othersDir.listFiles();
+            if (files != null) {
+                otherFiles.addAll(Arrays.asList(files));
+            }
+        }
+
+        try {
+            List<OtherModel> others = new ArrayList<>();
+            for (File file : otherFiles) {
+                String json = loadText(new FileInputStream(file));
+                OtherModel model = generateOtherModel(json);
+                others.add(model);
+            }
+
+            // sort the models
+            Collections.sort(others, new OtherComparator());
+
+            // how many different artifacts
+            int count = others.stream()
+                    .map(OtherModel::getArtifactId)
+                    .collect(toSet()).size();
+
+            // how many deprecated
+            long deprecated = others.stream()
+                    .filter(o -> "true".equals(o.getDeprecated()))
+                    .count();
+
+            // update the big readme file in the components dir
+            File file = new File(readmeExtensionsDir, "readme.adoc");
+
+            // update regular components
+            boolean exists = file.exists();
+            String changed = templateOthers(others, count, deprecated);
+            boolean updated = updateOthers(file, changed);
+
+            if (updated) {
+                getLog().info("Updated readme.adoc file: " + file);
+            } else if (exists) {
+                getLog().debug("No changes to readme.adoc file: " + file);
+            } else {
+                getLog().warn("No readme.adoc file: " + file);
+            }
+
+        } catch (IOException e) {
+            throw new MojoFailureException("Error due " + e.getMessage(), e);
+        }
+    }
+
     private String templateComponents(List<ComponentModel> models, int artifacts, long deprecated) throws MojoExecutionException {
         try {
             String template = loadText(UpdateDocExtensionsListMojo.class.getClassLoader().getResourceAsStream("readme-components.mvel"));
@@ -382,11 +387,11 @@ public class UpdateDocExtensionsListMojo extends AbstractMojo {
         }
     }
 
-    private String templateOthers(List<OtherModel> models, int artifacts, long deprecated) throws MojoExecutionException {
+    private String templateDataFormats(List<DataFormatModel> models, int artifacts, long deprecated) throws MojoExecutionException {
         try {
-            String template = loadText(UpdateDocExtensionsListMojo.class.getClassLoader().getResourceAsStream("readme-others.mvel"));
+            String template = loadText(UpdateDocExtensionsListMojo.class.getClassLoader().getResourceAsStream("readme-dataformats.mvel"));
             Map<String, Object> map = new HashMap<>();
-            map.put("others", models);
+            map.put("dataformats", models);
             map.put("numberOfArtifacts", artifacts);
             map.put("numberOfDeprecated", deprecated);
             String out = (String) TemplateRuntime.eval(template, map, Collections.singletonMap("util", MvelHelper.INSTANCE));
@@ -396,11 +401,11 @@ public class UpdateDocExtensionsListMojo extends AbstractMojo {
         }
     }
 
-    private String templateDataFormats(List<DataFormatModel> models, int artifacts, long deprecated) throws MojoExecutionException {
+    private String templateLanguages(List<LanguageModel> models, int artifacts, long deprecated) throws MojoExecutionException {
         try {
-            String template = loadText(UpdateDocExtensionsListMojo.class.getClassLoader().getResourceAsStream("readme-dataformats.mvel"));
+            String template = loadText(UpdateDocExtensionsListMojo.class.getClassLoader().getResourceAsStream("readme-languages.mvel"));
             Map<String, Object> map = new HashMap<>();
-            map.put("dataformats", models);
+            map.put("languages", models);
             map.put("numberOfArtifacts", artifacts);
             map.put("numberOfDeprecated", deprecated);
             String out = (String) TemplateRuntime.eval(template, map, Collections.singletonMap("util", MvelHelper.INSTANCE));
@@ -410,11 +415,11 @@ public class UpdateDocExtensionsListMojo extends AbstractMojo {
         }
     }
 
-    private String templateLanguages(List<LanguageModel> models, int artifacts, long deprecated) throws MojoExecutionException {
+    private String templateOthers(List<OtherModel> models, int artifacts, long deprecated) throws MojoExecutionException {
         try {
-            String template = loadText(UpdateDocExtensionsListMojo.class.getClassLoader().getResourceAsStream("readme-languages.mvel"));
+            String template = loadText(UpdateDocExtensionsListMojo.class.getClassLoader().getResourceAsStream("readme-others.mvel"));
             Map<String, Object> map = new HashMap<>();
-            map.put("languages", models);
+            map.put("others", models);
             map.put("numberOfArtifacts", artifacts);
             map.put("numberOfDeprecated", deprecated);
             String out = (String) TemplateRuntime.eval(template, map, Collections.singletonMap("util", MvelHelper.INSTANCE));
@@ -458,7 +463,7 @@ public class UpdateDocExtensionsListMojo extends AbstractMojo {
         }
     }
 
-    private boolean updateOthers(File file, String changed) throws MojoExecutionException {
+    private boolean updateDataFormats(File file, String changed) throws MojoExecutionException {
         if (!file.exists()) {
             return false;
         }
@@ -466,7 +471,7 @@ public class UpdateDocExtensionsListMojo extends AbstractMojo {
         try {
             String text = loadText(new FileInputStream(file));
 
-            String existing = StringHelper.between(text, "// others: START", "// others: END");
+            String existing = StringHelper.between(text, "// dataformats: START", "// dataformats: END");
             if (existing != null) {
                 // remove leading line breaks etc
                 existing = existing.trim();
@@ -474,17 +479,17 @@ public class UpdateDocExtensionsListMojo extends AbstractMojo {
                 if (existing.equals(changed)) {
                     return false;
                 } else {
-                    String before = StringHelper.before(text, "// others: START");
-                    String after = StringHelper.after(text, "// others: END");
-                    text = before + "// others: START\n" + changed + "\n// others: END" + after;
+                    String before = StringHelper.before(text, "// dataformats: START");
+                    String after = StringHelper.after(text, "// dataformats: END");
+                    text = before + "// dataformats: START\n" + changed + "\n// dataformats: END" + after;
                     writeText(file, text);
                     return true;
                 }
             } else {
                 getLog().warn("Cannot find markers in file " + file);
                 getLog().warn("Add the following markers");
-                getLog().warn("\t// others: START");
-                getLog().warn("\t// others: END");
+                getLog().warn("\t// dataformats: START");
+                getLog().warn("\t// dataformats: END");
                 return false;
             }
         } catch (Exception e) {
@@ -492,7 +497,7 @@ public class UpdateDocExtensionsListMojo extends AbstractMojo {
         }
     }
 
-    private boolean updateDataFormats(File file, String changed) throws MojoExecutionException {
+    private boolean updateLanguages(File file, String changed) throws MojoExecutionException {
         if (!file.exists()) {
             return false;
         }
@@ -500,7 +505,7 @@ public class UpdateDocExtensionsListMojo extends AbstractMojo {
         try {
             String text = loadText(new FileInputStream(file));
 
-            String existing = StringHelper.between(text, "// dataformats: START", "// dataformats: END");
+            String existing = StringHelper.between(text, "// languages: START", "// languages: END");
             if (existing != null) {
                 // remove leading line breaks etc
                 existing = existing.trim();
@@ -508,17 +513,17 @@ public class UpdateDocExtensionsListMojo extends AbstractMojo {
                 if (existing.equals(changed)) {
                     return false;
                 } else {
-                    String before = StringHelper.before(text, "// dataformats: START");
-                    String after = StringHelper.after(text, "// dataformats: END");
-                    text = before + "// dataformats: START\n" + changed + "\n// dataformats: END" + after;
+                    String before = StringHelper.before(text, "// languages: START");
+                    String after = StringHelper.after(text, "// languages: END");
+                    text = before + "// languages: START\n" + changed + "\n// languages: END" + after;
                     writeText(file, text);
                     return true;
                 }
             } else {
                 getLog().warn("Cannot find markers in file " + file);
                 getLog().warn("Add the following markers");
-                getLog().warn("\t// dataformats: START");
-                getLog().warn("\t// dataformats: END");
+                getLog().warn("\t// languages: START");
+                getLog().warn("\t// languages: END");
                 return false;
             }
         } catch (Exception e) {
@@ -526,7 +531,7 @@ public class UpdateDocExtensionsListMojo extends AbstractMojo {
         }
     }
 
-    private boolean updateLanguages(File file, String changed) throws MojoExecutionException {
+    private boolean updateOthers(File file, String changed) throws MojoExecutionException {
         if (!file.exists()) {
             return false;
         }
@@ -534,7 +539,7 @@ public class UpdateDocExtensionsListMojo extends AbstractMojo {
         try {
             String text = loadText(new FileInputStream(file));
 
-            String existing = StringHelper.between(text, "// languages: START", "// languages: END");
+            String existing = StringHelper.between(text, "// others: START", "// others: END");
             if (existing != null) {
                 // remove leading line breaks etc
                 existing = existing.trim();
@@ -542,17 +547,17 @@ public class UpdateDocExtensionsListMojo extends AbstractMojo {
                 if (existing.equals(changed)) {
                     return false;
                 } else {
-                    String before = StringHelper.before(text, "// languages: START");
-                    String after = StringHelper.after(text, "// languages: END");
-                    text = before + "// languages: START\n" + changed + "\n// languages: END" + after;
+                    String before = StringHelper.before(text, "// others: START");
+                    String after = StringHelper.after(text, "// others: END");
+                    text = before + "// others: START\n" + changed + "\n// others: END" + after;
                     writeText(file, text);
                     return true;
                 }
             } else {
                 getLog().warn("Cannot find markers in file " + file);
                 getLog().warn("Add the following markers");
-                getLog().warn("\t// languages: START");
-                getLog().warn("\t// languages: END");
+                getLog().warn("\t// others: START");
+                getLog().warn("\t// others: END");
                 return false;
             }
         } catch (Exception e) {
@@ -569,31 +574,33 @@ public class UpdateDocExtensionsListMojo extends AbstractMojo {
         }
     }
 
-    private static class OtherComparator implements Comparator<OtherModel> {
+    private static class DataFormatComparator implements Comparator<DataFormatModel> {
 
         @Override
-        public int compare(OtherModel o1, OtherModel o2) {
+        public int compare(DataFormatModel o1, DataFormatModel o2) {
             // lets sort by title
             return o1.getTitle().compareToIgnoreCase(o2.getTitle());
         }
     }
 
-    private static class DataFormatComparator implements Comparator<DataFormatModel> {
+    private static class LanguageComparator implements Comparator<LanguageModel> {
 
         @Override
-        public int compare(DataFormatModel o1, DataFormatModel o2) {
+        public int compare(LanguageModel o1, LanguageModel o2) {
             // lets sort by title
             return o1.getTitle().compareToIgnoreCase(o2.getTitle());
         }
+
     }
 
-    private static class LanguageComparator implements Comparator<LanguageModel> {
+    private static class OtherComparator implements Comparator<OtherModel> {
 
         @Override
-        public int compare(LanguageModel o1, LanguageModel o2) {
+        public int compare(OtherModel o1, OtherModel o2) {
             // lets sort by title
             return o1.getTitle().compareToIgnoreCase(o2.getTitle());
         }
+
     }
 
     private ComponentModel generateComponentModel(String json) {
@@ -620,24 +627,6 @@ public class UpdateDocExtensionsListMojo extends AbstractMojo {
         return component;
     }
 
-    private OtherModel generateOtherModel(String json) {
-        List<Map<String, String>> rows = JSonSchemaHelper.parseJsonSchema("other", json, false);
-
-        OtherModel other = new OtherModel();
-        other.setName(JSonSchemaHelper.getSafeValue("name", rows));
-        other.setTitle(JSonSchemaHelper.getSafeValue("title", rows));
-        other.setDescription(JSonSchemaHelper.getSafeValue("description", rows));
-        other.setFirstVersion(JSonSchemaHelper.getSafeValue("firstVersion", rows));
-        other.setLabel(JSonSchemaHelper.getSafeValue("label", rows));
-        other.setDeprecated(JSonSchemaHelper.getSafeValue("deprecated", rows));
-        other.setDeprecationNote(JSonSchemaHelper.getSafeValue("deprecationNote", rows));
-        other.setGroupId(JSonSchemaHelper.getSafeValue("groupId", rows));
-        other.setArtifactId(JSonSchemaHelper.getSafeValue("artifactId", rows));
-        other.setVersion(JSonSchemaHelper.getSafeValue("version", rows));
-
-        return other;
-    }
-
     private DataFormatModel generateDataFormatModel(String json) {
         List<Map<String, String>> rows = JSonSchemaHelper.parseJsonSchema("dataformat", json, false);
 
@@ -678,4 +667,22 @@ public class UpdateDocExtensionsListMojo extends AbstractMojo {
         return language;
     }
 
+    private OtherModel generateOtherModel(String json) {
+        List<Map<String, String>> rows = JSonSchemaHelper.parseJsonSchema("other", json, false);
+
+        OtherModel other = new OtherModel();
+        other.setName(JSonSchemaHelper.getSafeValue("name", rows));
+        other.setTitle(JSonSchemaHelper.getSafeValue("title", rows));
+        other.setDescription(JSonSchemaHelper.getSafeValue("description", rows));
+        other.setFirstVersion(JSonSchemaHelper.getSafeValue("firstVersion", rows));
+        other.setLabel(JSonSchemaHelper.getSafeValue("label", rows));
+        other.setDeprecated(JSonSchemaHelper.getSafeValue("deprecated", rows));
+        other.setDeprecationNote(JSonSchemaHelper.getSafeValue("deprecationNote", rows));
+        other.setGroupId(JSonSchemaHelper.getSafeValue("groupId", rows));
+        other.setArtifactId(JSonSchemaHelper.getSafeValue("artifactId", rows));
+        other.setVersion(JSonSchemaHelper.getSafeValue("version", rows));
+
+        return other;
+    }
+
 }


[camel-quarkus] 04/06: Add todo

Posted by da...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

davsclaus pushed a commit to branch fix245
in repository https://gitbox.apache.org/repos/asf/camel-quarkus.git

commit d9e10eb469f8d407999e032be006cf942422f9f2
Author: Claus Ibsen <cl...@gmail.com>
AuthorDate: Wed Oct 9 12:27:47 2019 +0200

    Add todo
---
 .../apache/camel/quarkus/maven/UpdateDocExtensionsListMojo.java   | 8 ++++++++
 1 file changed, 8 insertions(+)

diff --git a/tooling/maven/package-maven-plugin/src/main/java/org/apache/camel/quarkus/maven/UpdateDocExtensionsListMojo.java b/tooling/maven/package-maven-plugin/src/main/java/org/apache/camel/quarkus/maven/UpdateDocExtensionsListMojo.java
index 08a439b..b5e7697 100644
--- a/tooling/maven/package-maven-plugin/src/main/java/org/apache/camel/quarkus/maven/UpdateDocExtensionsListMojo.java
+++ b/tooling/maven/package-maven-plugin/src/main/java/org/apache/camel/quarkus/maven/UpdateDocExtensionsListMojo.java
@@ -188,6 +188,8 @@ public class UpdateDocExtensionsListMojo extends AbstractMojo {
                 getLog().warn("No readme.adoc file: " + file);
             }
 
+            // TODO: update websiteDocFile
+
         } catch (IOException e) {
             throw new MojoFailureException("Error due " + e.getMessage(), e);
         }
@@ -249,6 +251,8 @@ public class UpdateDocExtensionsListMojo extends AbstractMojo {
                 getLog().warn("No readme.adoc file: " + file);
             }
 
+            // TODO: update websiteDocFile
+
         } catch (IOException e) {
             throw new MojoFailureException("Error due " + e.getMessage(), e);
         }
@@ -304,6 +308,8 @@ public class UpdateDocExtensionsListMojo extends AbstractMojo {
                 getLog().warn("No readme.adoc file: " + file);
             }
 
+            // TODO: update websiteDocFile
+
         } catch (IOException e) {
             throw new MojoFailureException("Error due " + e.getMessage(), e);
         }
@@ -353,6 +359,8 @@ public class UpdateDocExtensionsListMojo extends AbstractMojo {
                 getLog().warn("No readme.adoc file: " + file);
             }
 
+            // TODO: update websiteDocFile
+
         } catch (IOException e) {
             throw new MojoFailureException("Error due " + e.getMessage(), e);
         }


[camel-quarkus] 03/06: Polished

Posted by da...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

davsclaus pushed a commit to branch fix245
in repository https://gitbox.apache.org/repos/asf/camel-quarkus.git

commit 3345f84ab01ccd911c787e3b32264ac104746b05
Author: Claus Ibsen <cl...@gmail.com>
AuthorDate: Wed Oct 9 12:27:09 2019 +0200

    Polished
---
 .../quarkus/maven/UpdateDocExtensionsListMojo.java | 29 ++++++----------------
 1 file changed, 7 insertions(+), 22 deletions(-)

diff --git a/tooling/maven/package-maven-plugin/src/main/java/org/apache/camel/quarkus/maven/UpdateDocExtensionsListMojo.java b/tooling/maven/package-maven-plugin/src/main/java/org/apache/camel/quarkus/maven/UpdateDocExtensionsListMojo.java
index b9d1148..08a439b 100644
--- a/tooling/maven/package-maven-plugin/src/main/java/org/apache/camel/quarkus/maven/UpdateDocExtensionsListMojo.java
+++ b/tooling/maven/package-maven-plugin/src/main/java/org/apache/camel/quarkus/maven/UpdateDocExtensionsListMojo.java
@@ -175,15 +175,11 @@ public class UpdateDocExtensionsListMojo extends AbstractMojo {
                     .filter(c -> "true".equals(c.getDeprecated()))
                     .count();
 
-            // update the big readme file in the core/components dir
-            File file;
-            file = new File(readmeExtensionsDir, "readme.adoc");
-
-            // update regular components
+            // update the big readme file in the extensions dir
+            File file = new File(readmeExtensionsDir, "readme.adoc");
             boolean exists = file.exists();
             String changed = templateComponents(components, count, deprecated);
             boolean updated = updateComponents(file, changed);
-
             if (updated) {
                 getLog().info("Updated readme.adoc file: " + file);
             } else if (exists) {
@@ -240,15 +236,11 @@ public class UpdateDocExtensionsListMojo extends AbstractMojo {
                 dataFormats.add(model);
             }
 
-            // update the big readme file in the core/components dir
-            File file;
-            file = new File(readmeExtensionsDir, "readme.adoc");
-
-            // update regular data formats
+            // update the big readme file in the extensions dir
+            File file = new File(readmeExtensionsDir, "readme.adoc");
             boolean exists = file.exists();
             String changed = templateDataFormats(dataFormats, count, deprecated);
             boolean updated = updateDataFormats(file, changed);
-
             if (updated) {
                 getLog().info("Updated readme.adoc file: " + file);
             } else if (exists) {
@@ -299,15 +291,11 @@ public class UpdateDocExtensionsListMojo extends AbstractMojo {
                     .filter(l -> "true".equals(l.getDeprecated()))
                     .count();
 
-            // update the big readme file in the core/components dir
-            File file;
-            file = new File(readmeExtensionsDir, "readme.adoc");
-
-            // update regular data formats
+            // update the big readme file in the extensions dir
+            File file = new File(readmeExtensionsDir, "readme.adoc");
             boolean exists = file.exists();
             String changed = templateLanguages(languages, count, deprecated);
             boolean updated = updateLanguages(file, changed);
-
             if (updated) {
                 getLog().info("Updated readme.adoc file: " + file);
             } else if (exists) {
@@ -352,14 +340,11 @@ public class UpdateDocExtensionsListMojo extends AbstractMojo {
                     .filter(o -> "true".equals(o.getDeprecated()))
                     .count();
 
-            // update the big readme file in the components dir
+            // update the big readme file in the extensions dir
             File file = new File(readmeExtensionsDir, "readme.adoc");
-
-            // update regular components
             boolean exists = file.exists();
             String changed = templateOthers(others, count, deprecated);
             boolean updated = updateOthers(file, changed);
-
             if (updated) {
                 getLog().info("Updated readme.adoc file: " + file);
             } else if (exists) {
diff --git a/tooling/maven/package-maven-plugin/src/main/java/org/apache/camel/quarkus/maven/PrepareExtensionsReadmeMojo.java b/tooling/maven/package-maven-plugin/src/main/java/org/apache/camel/quarkus/maven/UpdateDocExtensionsListMojo.java
similarity index 97%
rename from tooling/maven/package-maven-plugin/src/main/java/org/apache/camel/quarkus/maven/PrepareExtensionsReadmeMojo.java
rename to tooling/maven/package-maven-plugin/src/main/java/org/apache/camel/quarkus/maven/UpdateDocExtensionsListMojo.java
index e9ee00a..0cf24b4 100644
--- a/tooling/maven/package-maven-plugin/src/main/java/org/apache/camel/quarkus/maven/PrepareExtensionsReadmeMojo.java
+++ b/tooling/maven/package-maven-plugin/src/main/java/org/apache/camel/quarkus/maven/UpdateDocExtensionsListMojo.java
@@ -48,10 +48,15 @@ import static org.apache.camel.quarkus.maven.PackageHelper.loadText;
 import static org.apache.camel.quarkus.maven.PackageHelper.writeText;
 
 /**
  * Prepares the extensions/readme.adoc files content up to date with all the extensions that Apache Camel Quarkus ships.
  */
-@Mojo(name = "prepare-extensions-readme", threadSafe = true)
-public class PrepareExtensionsReadmeMojo extends AbstractMojo {
+@Mojo(name = "update-doc-extensions-list", threadSafe = true)
+public class UpdateDocExtensionsListMojo extends AbstractMojo {
 
     /**
      * The maven project.
@@ -365,7 +370,7 @@ public class PrepareExtensionsReadmeMojo extends AbstractMojo {
 
     private String templateComponents(List<ComponentModel> models, int artifacts, long deprecated) throws MojoExecutionException {
         try {
-            String template = loadText(PrepareExtensionsReadmeMojo.class.getClassLoader().getResourceAsStream("readme-components.mvel"));
+            String template = loadText(UpdateDocExtensionsListMojo.class.getClassLoader().getResourceAsStream("readme-components.mvel"));
             Map<String, Object> map = new HashMap<>();
             map.put("components", models);
             map.put("numberOfArtifacts", artifacts);
@@ -379,7 +384,7 @@ public class PrepareExtensionsReadmeMojo extends AbstractMojo {
 
     private String templateOthers(List<OtherModel> models, int artifacts, long deprecated) throws MojoExecutionException {
         try {
-            String template = loadText(PrepareExtensionsReadmeMojo.class.getClassLoader().getResourceAsStream("readme-others.mvel"));
+            String template = loadText(UpdateDocExtensionsListMojo.class.getClassLoader().getResourceAsStream("readme-others.mvel"));
             Map<String, Object> map = new HashMap<>();
             map.put("others", models);
             map.put("numberOfArtifacts", artifacts);
@@ -393,7 +398,7 @@ public class PrepareExtensionsReadmeMojo extends AbstractMojo {
 
     private String templateDataFormats(List<DataFormatModel> models, int artifacts, long deprecated) throws MojoExecutionException {
         try {
-            String template = loadText(PrepareExtensionsReadmeMojo.class.getClassLoader().getResourceAsStream("readme-dataformats.mvel"));
+            String template = loadText(UpdateDocExtensionsListMojo.class.getClassLoader().getResourceAsStream("readme-dataformats.mvel"));
             Map<String, Object> map = new HashMap<>();
             map.put("dataformats", models);
             map.put("numberOfArtifacts", artifacts);
@@ -407,7 +412,7 @@ public class PrepareExtensionsReadmeMojo extends AbstractMojo {
 
     private String templateLanguages(List<LanguageModel> models, int artifacts, long deprecated) throws MojoExecutionException {
         try {
-            String template = loadText(PrepareExtensionsReadmeMojo.class.getClassLoader().getResourceAsStream("readme-languages.mvel"));
+            String template = loadText(UpdateDocExtensionsListMojo.class.getClassLoader().getResourceAsStream("readme-languages.mvel"));
             Map<String, Object> map = new HashMap<>();
             map.put("languages", models);
             map.put("numberOfArtifacts", artifacts);


[camel-quarkus] 06/06: Remove build scripts no longer needed as we generate this via Camel Maven tooling like we do at Apache Camel

Posted by da...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

davsclaus pushed a commit to branch fix245
in repository https://gitbox.apache.org/repos/asf/camel-quarkus.git

commit 4da69a94fee548e2d75cec6aa53b9ca049928b09
Author: Claus Ibsen <cl...@gmail.com>
AuthorDate: Thu Oct 10 09:02:45 2019 +0200

    Remove build scripts no longer needed as we generate this via Camel Maven tooling like we do at Apache Camel
---
 build/scripts/list-camel-quarkus-extensions.groovy | 43 ----------------------
 .../ROOT/pages/_partials/common-extensions.adoc    |  5 ---
 .../ROOT/pages/_partials/component-extensions.adoc | 24 ------------
@@ -48,10 +48,15 @@ import static org.apache.camel.quarkus.maven.PackageHelper.loadText;
 
 /**
- * Prepares the extensions/readme.adoc files content up to date with all the extensions that Apache Camel Quarkus ships.
+ * Updates the documentation in:
+ *
+ * - extensions/readme.adoc
+ * - docs/modules/ROOT/pages/list-of-camel-quarkus-extensions.adoc
+ *
+ * to be up to date with all the extensions that Apache Camel Quarkus ships.
  */
 extensions/pom.xml                                 | 26 -------------
 4 files changed, 98 deletions(-)
